@@ -174,13 +174,14 @@ class pymakeplots:
         # ipdb.set_trace()
         return mask      
        
-    # def get_header_coord_arrays(self,hdr):
+    # def get_header_coord_arrays_wcs(self,hdr):
     #     self.wcs=wcs.WCS(hdr)
     #
     #     maxsize=np.max([hdr['NAXIS1'],hdr['NAXIS2'],hdr['NAXIS3']])
     #
     #     xp,yp=np.meshgrid(np.arange(0,maxsize),np.arange(0,maxsize))
     #     zp = xp.copy()
+    #     breakpoint()
     #     # import ipdb
     #     # ipdb.set_trace()
     #     # #coord = wcs.celestial.pixel_to_world(50, 50)
@@ -189,7 +190,7 @@ class pymakeplots:
     #     except:
     #         x,y,spectral,_ = self.wcs.all_pix2world(xp,yp,zp, 0,0) ## if stokes axis remains
     #
-    #     breakpoint()
+    #     #breakpoint()
     #     x1=np.median(x[0:hdr['NAXIS2'],0:hdr['NAXIS1']],0)
     #     y1=np.median(y[0:hdr['NAXIS2'],0:hdr['NAXIS1']],1)
     #     spectral1=spectral[0,0:hdr['NAXIS3']]
@@ -217,7 +218,7 @@ class pymakeplots:
     #     cd3= np.median(np.diff(v1))
     #     cd1= np.median(np.diff(x1))
     #     return x1,y1,v1,np.abs(cd1*3600),cd3
-        
+
     def get_header_coord_arrays(self,hdr):
        try:
            cd1=hdr['CDELT1']
@@ -226,9 +227,9 @@ class pymakeplots:
        except:
            cd1=hdr['CD1_1']
            cd2=hdr['CD2_2']
-       
-       cd1=(cd1/np.cos(np.deg2rad(hdr['CRVAL2'])))
-       
+
+       #cd1=(cd1/np.cos(np.deg2rad(hdr['CRVAL2'])))
+
        x1=((np.arange(0,hdr['NAXIS1'])-(hdr['CRPIX1']-1))*cd1) + hdr['CRVAL1']
        y1=((np.arange(0,hdr['NAXIS2'])-(hdr['CRPIX2']-1))*cd2) + hdr['CRVAL2']
 
@@ -373,7 +374,7 @@ class pymakeplots:
         
         
         self.xc=(self.xcoord_trim-self.obj_ra)*(-1) * 3600.
-        self.yc=(self.ycoord_trim-self.obj_dec) * 3600. / np.cos(np.deg2rad(self.obj_dec))
+        self.yc=(self.ycoord_trim-self.obj_dec) * 3600. #/ np.cos(np.deg2rad(self.obj_dec))
         
 
         if self.gal_distance == None:
@@ -553,7 +554,7 @@ class pymakeplots:
             
 
             wx,=np.where((np.abs((self.xcoord-self.obj_ra)*3600.) <= self.imagesize[0]))
-            wy,=np.where((np.abs((self.ycoord-self.obj_dec)*3600.) <= self.imagesize[1]*np.cos(np.deg2rad(self.obj_dec))))
+            wy,=np.where((np.abs((self.ycoord-self.obj_dec)*3600.) <= self.imagesize[1]))#*np.cos(np.deg2rad(self.obj_dec))))
             self.spatial_trim=[np.min(wx),np.max(wx),np.min(wy),np.max(wy)]        
         
         if self.spatial_trim == None:
